/*
 * Copyright 2018-2021 Elyra Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

describe('LSP', () => {
  beforeEach(() => {
    // read python file used for testing
    cy.bootstrapFile('helloworld.py');

    cy.resetJupyterLab();
  });

  afterEach(() => {
    // delete Python file used for testing
    cy.deleteFile('helloworld.py');
  });

  it('LSP extension is initialized', () => {
    // open Python file
    cy.openFile('helloworld.py');

    //check for lsp item on status bar
    cy.get('.lsp-statusbar-item ').find(
      '[title="Fully connected & initialized (1 virtual document)"]'
    );
  });
});
